<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="cs">
<context>
    <name>AuthFace</name>
    <message>
        <source>Face ID</source>
        <translation>Identifikace obličejem</translation>
    </message>
    <message>
        <source>Verification successful</source>
        <translation>Úspěšně ověřeno</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Ověření se nezdařilo – zbývá pouze jeden pokus</translation>
    </message>
    <message>
        <source>Verify your Face ID</source>
        <translation>Ověřte svou identifikaci obličejem</translation>
    </message>
    <message>
        <source>Face ID locked, use password please</source>
        <translation>Identifikace obličejem uzamčena – použijte prosím heslo</translation>
    </message>
    <message>
        <source>Device unavailable!</source>
        <translation>Zařízení není k dispozici!</translation>
    </message>
</context>
<context>
    <name>AuthFingerprint</name>
    <message>
        <source>Verify your fingerprint</source>
        <translation>Ověřit otisk prstu</translation>
    </message>
    <message>
        <source>Verification successful</source>
        <translation>Úspěšně ověřeno</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>Ověření se nezdařilo, zbývá %n pokus</numerusform><numerusform>Ověření se nezdařilo, zbývají %n pokusy</numerusform><numerusform>Ověření se nezdařilo, zbývá %n pokusů</numerusform><numerusform>Ověření se nezdařilo, zbývají %n pokusy</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Ověření se nezdařilo – zbývá pouze jeden pokus</translation>
    </message>
    <message>
        <source>Fingerprint locked, use password please</source>
        <translation>Možnost použití otisku zamčena – napište namísto něj heslo</translation>
    </message>
</context>
<context>
    <name>AuthIris</name>
    <message>
        <source>Iris ID</source>
        <translation>Identifikace duhovkou</translation>
    </message>
    <message>
        <source>Verification successful</source>
        <translation>Úspěšně ověřeno</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Ověření se nezdařilo – zbývá pouze jeden pokus</translation>
    </message>
    <message>
        <source>Verify your Iris ID</source>
        <translation>Ověřte identifikaci duhovkou</translation>
    </message>
    <message>
        <source>Iris ID locked, use password please</source>
        <translation>Identifikace duhovkou uzamčena – použijte heslo</translation>
    </message>
</context>
<context>
    <name>AuthPassword</name>
    <message>
        <source>Verification successful</source>
        <translation>Úspěšně ověřeno</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>Ověření se nezdařilo – zbývá %n pokus</numerusform><numerusform>Ověření se nezdařilo – zbývají %n pokusy</numerusform><numerusform>Ověření se nezdařilo – zbývá %n pokusů</numerusform><numerusform>Ověření se nezdařilo – zbývají %n pokusy</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Ověření se nezdařilo – zbývá pouze jeden pokus</translation>
    </message>
    <message>
        <source>Wrong Password</source>
        <translation>Chybné heslo</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Heslo</translation>
    </message>
    <message>
        <source>Please try again 1 minute later</source>
        <translation>Prosím, zkuste znovu za 1 minutu</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Reset Password</source>
        <translation>Vynulovat heslo</translation>
    </message>
    <message>
        <source>Forgot password?</source>
        <translation>Zapomněli jste heslo?</translation>
    </message>
</context>
<context>
    <name>AuthSingle</name>
    <message>
        <source>Please try again 1 minute later</source>
        <translation>Prosím, zkuste znovu za 1 minutu</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation><numerusform>Prosím, zkuste znovu za %n minutu</numerusform><numerusform>Prosím, zkuste znovu za %n minuty</numerusform><numerusform>Prosím, zkuste znovu za %n minut</numerusform><numerusform>Prosím, zkuste znovu za %n minuty</numerusform></translation>
    </message>
    <message>
        <source>Reset Password</source>
        <translation>Vynulovat heslo</translation>
    </message>
    <message>
        <source>Forgot password?</source>
        <translation>Zapomněli jste heslo?</translation>
    </message>
</context>
<context>
    <name>AuthUKey</name>
    <message>
        <source>Verification successful</source>
        <translation>Úspěšně ověřeno</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>Ověření se nezdařilo – zbývá %d pokus</numerusform><numerusform>Ověření se nezdařilo – zbývají %n pokusy</numerusform><numerusform>Ověření se nezdařilo – zbývá %d pokusů</numerusform><numerusform>Ověření se nezdařilo – zbývají %n pokusy</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Ověření se nezdařilo – zbývá pouze jeden pokus</translation>
    </message>
    <message>
        <source>Wrong PIN</source>
        <translation>Nesprávný PIN</translation>
    </message>
    <message>
        <source>UKey is required</source>
        <translation>Je zapotřebí UKey</translation>
    </message>
    <message>
        <source>Enter your PIN</source>
        <translation>Zadejte svůj PIN</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minute(s) later</source>
        <translation><numerusform>Prosím, zkuste znovu za %n minutu</numerusform><numerusform>Prosím, zkuste znovu za %n minuty</numerusform><numerusform>Prosím, zkuste znovu za %n minut</numerusform><numerusform>Prosím, zkuste znovu za %n minuty</numerusform></translation>
    </message>
    <message>
        <source>Please try again 1 minute later</source>
        <translation>Prosím, zkuste znovu za 1 minutu</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
</context>
<context>
    <name>AuthWidget</name>
    <message>
        <source>Account</source>
        <translation>Účet</translation>
    </message>
    <message numerus="yes">
        <source>Your password will expire in %n days, please change it timely</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Password expired, please change</source>
        <translation>Platnost hesla skončila – prosím změňte si ho</translation>
    </message>
</context>
<context>
    <name>GreeterWorker</name>
    <message>
        <source>Wrong account</source>
        <translation>Nesprávný účet</translation>
    </message>
    <message>
        <source>Wrong Password</source>
        <translation>Chybné heslo</translation>
    </message>
</context>
<context>
    <name>InhibitWarnView</name>
    <message>
        <source>Cancel</source>
        <translation>Zrušit</translation>
    </message>
</context>
<context>
    <name>LockContent</name>
    <message>
        <source>Lock Screen</source>
        <translation>Uzamknout obrazovku</translation>
    </message>
    <message>
        <source>Failed to lock screen</source>
        <translation>Nepodařilo se uzamknout obrazovku</translation>
    </message>
</context>
<context>
    <name>LockWorker</name>
    <message>
        <source>Fingerprint verification timed out, please enter your password manually</source>
        <translation>Překročen časový limit pro pokus o ověření se otiskem prstu – zadejte namísto toho heslo ručně</translation>
    </message>
    <message>
        <source>Failed to match fingerprint</source>
        <translation>Nepodařilo se najít v otisku shodu</translation>
    </message>
</context>
<context>
    <name>MultiUsersWarningView</name>
    <message>
        <source>Cancel</source>
        <translation>Zrušit</translation>
    </message>
    <message>
        <source>The above users are still logged in and data will be lost due to shutdown, are you sure you want to shut down?</source>
        <translation>Výše uvedení uživatelé jsou pořád ještě přihlášení a vypnutím mohou přijít o data – opravdu chcete počítač vypnout?</translation>
    </message>
    <message>
        <source>The above users are still logged in and data will be lost due to reboot, are you sure you want to reboot?</source>
        <translation>Výše uvedení uživatelé jsou pořád ještě přihlášení a restartováním mohou přijít o data – opravdu chcete počítač restartovat?</translation>
    </message>
</context>
<context>
    <name>SessionWidget</name>
    <message>
        <source>You have enabled the high system security level, thus cannot switch to the Wayland mode, please disable the high security level in Security Center and try again.</source>
        <translation>Zapnuli jste vysokou úroveň zabezpečení systému, proto není možné se přepnout do režimu Wayland. Vypněte vysoký stupeň zabezpečení v Centru zabezpečení a zkuste to znovu.</translation>
    </message>
</context>
<context>
    <name>ShutdownWidget</name>
    <message>
        <source>Shut down</source>
        <translation>Vypnout</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Restartovat</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Uspat</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Uspat na disk</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Uzamknout</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Odhlásit se</translation>
    </message>
    <message>
        <source>Switch user</source>
        <translation>Přepnout uživatele</translation>
    </message>
    <message>
        <source>Switch system</source>
        <translation>Přepnout systém</translation>
    </message>
</context>
<context>
    <name>SystemMonitor</name>
    <message>
        <source>Start system monitor</source>
        <translation>Spustit Systémové prostředky</translation>
    </message>
</context>
<context>
    <name>WarningContent</name>
    <message>
        <source>The programs are preventing the computer from shutting down, and forcing shut down may cause data loss.</source>
        <translation>Některé ze spuštěných programů brání vypnutí počítače. Jeho vynucení může způsobit ztrátu dat.</translation>
    </message>
    <message>
        <source>To close the program, click Cancel, and then close the program.</source>
        <translation>Pro zavření programu klepněte na Zrušit a potom program zavřete.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from reboot, and forcing reboot may cause data loss.</source>
        <translation>Některé ze spuštěných programů brání v restartování počítače. Jeho vynucení může způsobit ztrátu dat.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from suspend, and forcing suspend may cause data loss.</source>
        <translation>Některé ze spuštěných programů brání uspání do paměti. Jeho vynucení může způsobit ztrátu dat.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from hibernate, and forcing hibernate may cause data loss.</source>
        <translation>Některé ze spuštěných programů brání uspání na disk. Jeho vynucení může způsobit ztrátu dat.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from log out, and forcing log out may cause data loss.</source>
        <translation>Některé ze spuštěných programů brání odhlášení. Jeho vynucení může způsobit ztrátu dat.</translation>
    </message>
    <message>
        <source>Shut down</source>
        <translation>Vypnout</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Restartovat</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Uspat do paměti</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Uspat na disk</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Odhlásit se</translation>
    </message>
    <message>
        <source>Are you sure you want to shut down?</source>
        <translation>Opravdu chcete počítač vypnout?</translation>
    </message>
    <message>
        <source>Are you sure you want to reboot?</source>
        <translation>Opravdu chcete počítač restartovat?</translation>
    </message>
    <message>
        <source>Are you sure you want to log out?</source>
        <translation>Opravdu se chcete odhlásit?</translation>
    </message>
</context>
<context>
    <name>dss::module::NetworkModule</name>
    <message>
        <source>Turn on</source>
        <translation>Zapnout</translation>
    </message>
    <message>
        <source>Turn off</source>
        <translation>Vypnout</translation>
    </message>
</context>
</TS>